==> healthrian_visualization_support-1.0.36.tar.gz: lib/src/widgets/wear_cardio_t/control_panel_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

class ControlPanelWearT extends StatelessWidget {
  const ControlPanelWearT({super.key});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#1',
          onPressed: () async {
            BLEManager().setEnable(enableList: [false, false, true]);
            await BLEManager().connectDevice();
            await BLEManager().registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#2',
          onPressed: () async {
            BLEManager().setEnable(enableList: [false, false, true]);
            await BLEManager().startMeasurement();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#3',
          onPressed: () async {
            BLEManager().setEnable(enableList: [false, false, true]);
            await BLEManager().pauseMeasurement();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#4',
          onPressed: () async {
            BLEManager().setEnable(enableList: [false, false, true]);
            await BLEManager().stopMeasurement();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#5',
          onPressed: () {
            BLEManager().setEnable(enableList: [false, false, true]);
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}

==> healthrian_visualization_support-1.1.7.tar.gz: lib/src/widgets/wear_cardio_t/control_panel_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

class ControlPanelWearT extends StatelessWidget {
  const ControlPanelWearT({super.key});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#1',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, false, true]);
            await BLEManager().connectDevice();
            await BLEManager().registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#2',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, false, true]);
            await BLEManager().startMeasurement();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#3',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, false, true]);
            await BLEManager().pauseMeasurement();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#4',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, false, true]);
            await BLEManager().stopMeasurement();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearT#5',
          onPressed: () {
            BLEManager().setMode(enableList: [false, false, true]);
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}
